#define SAMPLE_SIZE 10

#define k_nearest 5 //k nearest

#define BUFFER_SIZE 6

#define JAMMERIMGPATH DATA_DIR "/jammer"

#define JAMMERSOUNDPATH DATA_DIR "/jammer/jammersounds"


void start_jammer();
